.. currentmodule:: clease.montecarlo.trial_move_generator

Trial Move Generators
=======================

Trial moves used in Monte Carlo (MC) sampling in Clease are provided from
:class:`clease.montecarlo.trial_move_generator.TrialMoveGenerator` classes.


The API
--------

.. autoclass:: TrialMoveGenerator
    :members:

.. autoclass:: SingleTrialMoveGenerator
    :members:

.. autoclass:: RandomFlip
    :members:

.. autoclass:: RandomSwap
    :members:

.. autoclass:: MixedSwapFlip
    :members:

.. autoclass:: RandomFlipWithinBasis
    :members:
